/*

  Author(s): Ilja V. Ryndin (ryndin@pinebrush.com)

*/

#ifndef MACCATEGORYLISTWIDGET_H
#define MACCATEGORYLISTWIDGET_H

#include "parsec_mac_qt5_global.h"

#include <parsec/mac.h>

#include <QListWidget>

namespace ParsecQt5
{

class PARSEC_MAC_QT5_EXPORT MacCategoryListWidget : public QListWidget
{
    Q_OBJECT

public:
    static bool categoryListWidgetItemLessThen( QListWidgetItem * /*left*/, QListWidgetItem * /*right*/ );

    MacCategoryListWidget( QWidget *parent = nullptr );
    MacCategoryListWidget( uid_t uid, QWidget *parent = nullptr );

    virtual ~MacCategoryListWidget();

    bool isSuitable();
    bool isValid();

    bool hasAvailableCategories();

    mac_cat_t minimumValue();
    mac_cat_t maximumValue();

    mac_cat_t value();

    bool rebuild();
    bool isRebuilt() const;

public slots:

    bool setUid(uid_t);
    bool setMinimumValue(mac_cat_t);
    bool setMaximumValue(mac_cat_t);
    bool setValue(mac_cat_t);

signals:
    void valueChanged( mac_cat_t );

private slots:
    void itemChanged( QListWidgetItem *);

private:
    int position(mac_cat_t);
    mac_cat_t nullToMax( mac_cat_t value );

    static mac_cat_t cat4Item(const QListWidgetItem *item);
    mac_cat_t cat4Item(int num);

    mac_cat_t m_minimumValue;
    mac_cat_t m_maximumValue;

    bool m_isUid;
    uid_t m_uid;

    mac_cat_t userMinVal;
    mac_cat_t userMaxVal;

    bool valid, suitable;
    bool m_isRebuilt { false };
};

} // namespace ParsecQt5

#endif // MACCATEGORYLISTWIDGET_H
